@@ -73,7 +73,6 @@ class ThemeInstaller(Tweak):
                 try:
                     self._settings = GSettingsSetting(ThemeInstaller.THEME_GSETTINGS_SCHEMA)
                     name = self._settings.get_value(ThemeInstaller.THEME_GSETTINGS_NAME)
-                    print "!!!!", name
                     error = None
                 except:
                     error = "User Theme extension schema missing"
@@ -157,6 +156,7 @@ TWEAK_GROUPS = (
         TweakGroup(
             "Shell",
             GSettingsSwitchTweak("org.gnome.shell.clock", "show-date", schema_filename="org.gnome.shell.gschema.xml"),
+            GSettingsSwitchTweak("org.gnome.shell.calendar", "show-weekdate", schema_filename="org.gnome.shell.gschema.xml"),
             ShowWindowButtons(size_group=sg),
             ThemeInstaller(size_group=sg),
             GSettingsComboEnumTweak("org.gnome.settings-daemon.plugins.power", "lid-close-battery-action", size_group=sg),
